package ActiveState::Config::Depend;

use strict;
use base qw(Exporter);
our @EXPORT_OK = qw(config_getdeps config_mtime_deps);

sub config_getdeps {
    my $file = shift;
    my @dep;
    my $dir;
    open(my $fh, "<", $file) || return;
    local $_;
    while (<$fh>) {
	next unless s/^\s*!\s*include\s+//;
	chomp;
	unless (m,^/,) {
	    unless ($dir) {
		require File::Basename;
		$dir = File::Basename::dirname($file);
	    }
	    $_ = join("/", $dir, $_);
	}
	my @inc = glob($_);
	for my $f (@inc) {
	    push(@dep, $f, config_getdeps($f));
	}
    }
    @dep;
}

sub config_mtime_deps {
    my $file = shift;
    my $mtime = (stat $file)[9] || return undef;
    for my $f (config_getdeps($file)) {
	my $m = (stat $f)[9];
	next unless defined $m;
	$mtime = $m if $m > $mtime;
    }
    return $mtime;
}

1;

__END__

=head1 NAME

ActiveState::Config::Depend - Find configuration file dependencies

=head1 SYNOPSIS

  use ActiveState::Config::Depend qw(config_getdeps config_mtime_deps);

  my @dep   = config_getdeps("foo.conf");
  my $mtime = config_mtime_deps("foo.conf");

=head1 DESCRIPTION

This module can export the following functions:

=over

=item @deps = config_getdeps( $file )

This function return all dependencies for a given configuration file.
Dependencies are defined as files that will be included by the given
configuration file.

=item $mtime = config_mtime_deps( $file )

This function return the time that the configuration file or any of
its dependencies last were modified.

=back

=cut
